#
# spec file for package headscale
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           headscale
Version:        0.23.0
Release:        1.1
Summary:        An open source, self-hosted implementation of the Tailscale control server
License:        BSD-3-Clause
URL:            https://headscale.net
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        headscale.sysusers
Source3:        headscale.tmpfs.conf
Source4:        headscale.systemd.service
Source5:        config-example.yaml
Source6:        derp-example.yaml
BuildRequires:  golang-packaging
BuildRequires:  zstd
Suggests:       wireguard-tools
Suggests:       postgresql-server

%description
Headscale aims to implement a self-hosted, open source alternative to the Tailscale control server. Headscale's goal is to provide self-hosters and hobbyists with an open-source server they can use for their projects and labs. It implements a narrow scope, a single Tailnet, suitable for a personal use, or a small open-source organisation.

%prep
%autosetup -a1

%build
go build -v -buildmode=pie -mod=vendor -tags "ts2019" -ldflags "-s -w -X github.com/juanfont/headscale/cmd/headscale/cli.Version=%{version}" ./cmd/headscale

%install
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}
install -D -m 755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m 644 %{SOURCE2} %{buildroot}/usr/lib/sysusers.d/%{name}.conf
install -D -m 644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -D -m 644 %{SOURCE4} %{buildroot}/usr/lib/systemd/system/%{name}.service
%if 0%{?suse_version} == 1500
install -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}/config-example.yaml
install -D -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/%{name}/config-derp.yaml
%else
install -D -m 644 %{SOURCE5} %{buildroot}/%{_distconfdir}/%{name}/config-example.yaml
install -D -m 644 %{SOURCE6} %{buildroot}/%{_distconfdir}/%{name}/derp-example.yaml
%endif

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_sharedstatedir}/%{name}
%if 0%{suse_version} == 1500
%{_sysconfdir}/%{name}
%else
%dir %{_distconfdir}/%{name}
%{_distconfdir}/%{name}/*
%endif
/usr/lib/sysusers.d/%{name}.conf
/usr/lib/tmpfiles.d/%{name}.conf
/usr/lib/systemd/system/%{name}.service

%changelog
* Wed Sep 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.0:
  * Code reorganisation, a lot of code has moved
  * Change the structure of database configuration, see config-example.yaml
  - Old structure has been remove and the configuration must be converted
  - Adds additional configuration for PostgreSQL for setting max open,
    idle connection and idle connection lifetime
  * API: Machine is now Node
  * Remove support for older Tailscale clients (supported >=1.42)
  * Headscale checks that at least one DERP is defined at start
  * Embedded DERP server requires a private key
  * Prefixes are now defined per v4 and v6 range
  * MagicDNS domains no longer contain usernames
  * YAML files are no longer supported for headscale policy (use HuJSON)
  * DNS configuration has been restructured
  * Use versioned migrations
  * Make the OIDC callback page better
  * SSH support
  * State management has been improved
  * Use error group handling to ensure tests actually pass
  * Fix hang on SIGTERM
  * Send logs to stderr by default
  * Fix TS-2023-006 security UPnP issue
  * Turn off gRPC logging
  * Added the possibility to manually create a DERP-map entry
  * Add support for deleting api keys
  * Add command to backfill IP addresses for nodes missing IPs from configured prefixes
  * Log available update as warning
  * Add autogroup:internet to Policy
  * Restore foreign keys and add constraints
  * Make registration page easier to use on mobile devices
  * Make write-ahead-log default on and configurable for SQLite
  * Add APIs for managing headscale policy
  * Fix for registering nodes using preauthkeys when running
    on a postgres database in a non-UTC timezone
  * Make sure integration tests cover postgres for all scenarios
  * CLI commands (all except serve) only requires minimal configuration
  * CLI results are now concistently sent to stdout and errors to stderr
  * Fix issue where shutting down headscale would hang
  * add shutdown that asserts if headscale had panics
* Thu Apr 18 2024 Richard Rahl <rrahl0@disroot.org>
- remove CAP_CHOWN from systemd unit file, as it's unneeded
* Wed Dec 20 2023 Richard Rahl <rrahl0@proton.me>
- initial packaging
